@@ -18,7 +18,7 @@ pub(crate) struct ChanBuilder<R: Runtime> {
     /// Asynchronous runtime for TLS, TCP, spawning, and timeouts.
     runtime: R,
     /// Object to build TLS connections.
-    tls_connector: <R as TlsProvider>::Connector,
+    tls_connector: <R as TlsProvider<R::TcpStream>>::Connector,
 }
 
 impl<R: Runtime> ChanBuilder<R> {
@@ -62,9 +62,9 @@ impl<R: Runtime> ChanBuilder<R> {
 
         // 1. Negotiate the TLS connection.
 
-        // TODO: This just uses the first address. Instead we could be smarter,
-        // or use "happy eyeballs, or whatever.  Maybe we will want to
-        // refactor as we do so?
+        // TODO: This just uses the first address. Instead we could be
+        // smarter, or use "happy eyeballs", or whatever.  Maybe we will
+        // want to refactor as we do so?
         let addr = target
             .addrs()
             .get(0)
@@ -72,10 +72,13 @@ impl<R: Runtime> ChanBuilder<R> {
 
         tracing::info!("Negotiating TLS with {}", addr);
 
+        // Establish a TCP connection.
+        let stream = self.runtime.connect(addr).await?;
+
         // TODO: add a random hostname here if it will be used for SNI?
         let tls = self
             .tls_connector
-            .connect_unvalidated(addr, "ignored")
+            .negotiate_unvalidated(stream, "ignored")
             .await?;
 
         let peer_cert = tls
