@@ -18,6 +18,7 @@
 #![deny(missing_docs)]
 #![warn(noop_method_call)]
 #![deny(unreachable_pub)]
+#![deny(clippy::all)]
 #![deny(clippy::await_holding_lock)]
 #![deny(clippy::cargo_common_metadata)]
 #![deny(clippy::cast_lossless)]
@@ -51,7 +52,7 @@ mod mgr;
 #[cfg(test)]
 mod testing;
 
-use tor_linkspec::ChanTarget;
+use tor_linkspec::{ChanTarget, OwnedChanTarget};
 use tor_proto::channel::Channel;
 
 pub use err::Error;
@@ -88,7 +89,7 @@ impl<R: Runtime> ChanMgr<R> {
     /// or fail depending on its outcome.
     pub async fn get_or_launch<T: ChanTarget + ?Sized>(&self, target: &T) -> Result<Arc<Channel>> {
         let ed_identity = target.ed_identity();
-        let targetinfo = target.to_owned();
+        let targetinfo = OwnedChanTarget::from_chan_target(target);
 
         let chan = self.mgr.get_or_launch(*ed_identity, targetinfo).await?;
         // Double-check the match to make sure that the RSA identity is
